@@ -39,7 +39,7 @@ def _str_to_bool(informal_bool: str) -> bool:
         return True
     if informal_bool.lower() in ('false', 'no', 'n', 'off', '0'):
         return False
-    raise ValueError
+    raise ValueError  # pragma: no cover
 
 
 def _str_to_num(informal_num: str) -> int | float:
@@ -58,15 +58,18 @@ def _str_to_num(informal_num: str) -> int | float:
     try:
         num = float(informal_num)
     except ValueError as e:
-        try:
-            num = int(informal_num, 16)
-        except Exception:
-            raise ValueError(': '.join(e.args))
-        else:
-            return num
+        for prefix, base in {'0x': 16, '0o': 8, '0b': 2}.items():
+            if informal_num.lower().startswith(prefix):
+                try:
+                    num = int(informal_num, base)
+                except Exception:  # pragma: no cover
+                    raise ValueError(': '.join(e.args))
+                else:
+                    return num
+        raise e  # pragma: no cover
     try:
         inum = int(num)
-    except ValueError:
+    except (ValueError, OverflowError):
         return num
     else:
         return inum if num == inum else num
@@ -146,7 +149,7 @@ def cast_stringy_data(
             continue
         try:
             surgeon.set_value(match.path, _str_to_bool(match.node))
-        except ValueError as e:
+        except ValueError as e:  # pragma: no cover
             raise ValueError(': '.join((*e.args, str(match.path))))
 
     for match in _non_null_matches(surgeon, *num_paths):
@@ -154,7 +157,7 @@ def cast_stringy_data(
             continue
         try:
             num = _str_to_num(match.node)
-        except ValueError as e:
+        except ValueError as e:  # pragma: no cover
             raise ValueError(': '.join(e.args + (str(match.path),)))
         else:
             surgeon.set_value(match.path, num)
@@ -176,7 +179,7 @@ def cast_stringy_data(
             except ValueError:
                 try:
                     val = time.fromisoformat(match.node)
-                except Exception as e:
+                except Exception as e:  # pragma: no cover
                     raise e
                 else:
                     val = f"{time_marker}{val.isoformat()}"
