@@ -1,6 +1,6 @@
 from commands import nt2toml, toml2nt
 from plumbum import local
-from utils import casting_args_from_schema_file
+from utils import assert_file_content, casting_args_from_schema_file
 from ward import skip, test
 
 try:
@@ -27,7 +27,7 @@ for input_toml_name, output_nt_name in {
     def _(input_toml_name=input_toml_name, output_nt_name=output_nt_name):
         expected_file = SAMPLES / f"{output_nt_name}.nt"
         output = toml2nt(SAMPLES / f"{input_toml_name}.toml")
-        assert output == expected_file.read()
+        assert_file_content(expected_file, output)
 
 
 @skip("TOML support not enabled", when=TOML_DISABLED)
@@ -35,7 +35,7 @@ for input_toml_name, output_nt_name in {
 def _():
     expected_file = SAMPLES / 'untyped.toml'
     output = nt2toml(SAMPLES / 'base.nt')
-    assert output == expected_file.read()
+    assert_file_content(expected_file, output)
 
 
 @skip("TOML support not enabled", when=TOML_DISABLED)
@@ -43,7 +43,7 @@ def _():
 def _():
     expected_file = SAMPLES / 'lines.toml'
     output = nt2toml(SAMPLES / 'lines.nt')
-    assert output == expected_file.read()
+    assert_file_content(expected_file, output)
 
 
 for schema_file in SAMPLES // 'base.*.types.nt':
@@ -53,7 +53,7 @@ for schema_file in SAMPLES // 'base.*.types.nt':
     def _(schema_file=schema_file):
         expected_file = SAMPLES / f"typed_{schema_file.name.split('.')[1]}.toml"
         output = nt2toml(SAMPLES / 'base.nt', schema_files=(schema_file,))
-        assert output == expected_file.read()
+        assert_file_content(expected_file, output)
 
     @skip("TOML support not enabled", when=TOML_DISABLED)
     @test(f"NestedText -> TOML [casting args from schema: {schema_file.name}]")
@@ -61,7 +61,7 @@ for schema_file in SAMPLES // 'base.*.types.nt':
         casting_args = casting_args_from_schema_file(schema_file, ('number', 'boolean'))
         expected_file = SAMPLES / f"typed_{schema_file.name.split('.')[1]}.toml"
         output = nt2toml(SAMPLES / 'base.nt', **casting_args)
-        assert output == expected_file.read()
+        assert_file_content(expected_file, output)
 
 
 @skip("TOML support not enabled", when=TOML_DISABLED)
@@ -73,7 +73,7 @@ def _():
         schema_files=(SAMPLES / 'base.bool.types.nt',),
         **casting_args_from_schema_file(SAMPLES / 'base.num.types.nt', ('number', 'boolean')),
     )
-    assert output == expected_file.read()
+    assert_file_content(expected_file, output)
 
 
 @skip("TOML support not enabled", when=TOML_DISABLED)
@@ -84,7 +84,7 @@ def _():
         SAMPLES / 'base.nt',
         schema_files=(SAMPLES / 'base.bool.types.nt', SAMPLES / 'base.num.types.nt'),
     )
-    assert output == expected_file.read()
+    assert_file_content(expected_file, output)
 
 
 for input_file, expected_file, schema_file in (
@@ -96,7 +96,7 @@ for input_file, expected_file, schema_file in (
     @test(f"NestedText -> TOML [schema file: {schema_file.name}]")
     def _(input_file=input_file, expected_file=expected_file, schema_file=schema_file):
         output = nt2toml(input_file, schema_files=(schema_file,))
-        assert output == expected_file.read()
+        assert_file_content(expected_file, output)
 
     casting_args = casting_args_from_schema_file(schema_file, ('date',))
 
@@ -104,4 +104,4 @@ for input_file, expected_file, schema_file in (
     @test(f"NestedText -> TOML [casting args: {', '.join(casting_args)}]")
     def _(input_file=input_file, expected_file=expected_file, casting_args=casting_args):
         output = nt2toml(input_file, **casting_args)
-        assert output == expected_file.read()
+        assert_file_content(expected_file, output)
